@@ -15,8 +15,11 @@ def _guess_lib_name():
 
 
 for name in _guess_lib_name():
-    _libchromaprint = ctypes.cdll.LoadLibrary(name)
-    break
+    try:
+        _libchromaprint = ctypes.cdll.LoadLibrary(name)
+        break
+    except OSError:
+        pass
 else:
     raise ImportError("couldn't find libchromaprint")
 
@@ -45,6 +48,9 @@ _libchromaprint.chromaprint_get_fingerprint.restype = ctypes.c_int
 _libchromaprint.chromaprint_decode_fingerprint.argtypes = (ctypes.POINTER(ctypes.c_char), ctypes.c_int, ctypes.POINTER(ctypes.POINTER(ctypes.c_int32)), ctypes.POINTER(ctypes.c_int), ctypes.POINTER(ctypes.c_int), ctypes.c_int)
 _libchromaprint.chromaprint_decode_fingerprint.restype = ctypes.c_int
 
+_libchromaprint.chromaprint_encode_fingerprint.argtypes = (ctypes.POINTER(ctypes.c_int32), ctypes.c_int, ctypes.c_int, ctypes.POINTER(ctypes.POINTER(ctypes.c_char)), ctypes.POINTER(ctypes.c_int), ctypes.c_int)
+_libchromaprint.chromaprint_encode_fingerprint.restype = ctypes.c_int
+
 _libchromaprint.chromaprint_dealloc.argtypes = (ctypes.c_void_p,)
 _libchromaprint.chromaprint_dealloc.restype = None
 
@@ -77,7 +83,6 @@ class Fingerprinter(object):
         _libchromaprint.chromaprint_dealloc(fingerprint_ptr)
         return fingerprint
 
-
 def decode_fingerprint(data, base64=True):
     result_ptr = ctypes.POINTER(ctypes.c_int32)()
     result_size = ctypes.c_int()
@@ -87,3 +92,14 @@ def decode_fingerprint(data, base64=True):
     _libchromaprint.chromaprint_dealloc(result_ptr)
     return result, algorithm.value
 
+def encode_fingerprint(fingerprint, algorithm, base64=True):
+    fp_array = (ctypes.c_int * len(fingerprint))()
+    for i in range(len(fingerprint)):
+        fp_array[i] = fingerprint[i]
+    result_ptr = ctypes.POINTER(ctypes.c_char)()
+    result_size = ctypes.c_int()
+    _libchromaprint.chromaprint_encode_fingerprint(fp_array, len(fingerprint), algorithm, ctypes.byref(result_ptr), ctypes.byref(result_size), 1 if base64 else 0)
+    result = result_ptr[:result_size.value]
+    _libchromaprint.chromaprint_dealloc(result_ptr)
+    return result
+
